iterz

package module
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 12, 2024 License: MIT Imports: 1 Imported by: 0

README

gopherz

ezpkg.io/iterz

PkgGoDev GitHub License version

Package iterz extends the standard library iter with additional functions.

Installation

go get -u ezpkg.io/iterz@v0.2.2

Features

Currently, it provides the following functions:

  • Nil[V]() iter.Seq[V]: returns an iterator that yields nothing.
  • Nil2[K, V]() iter.Seq2[K, V]: returns an iterator that yields nothing.
// Nil return an iter.Seq that yields nothing.
func Nil[V any]() iter.Seq[V] {
	return func(yield func(V) bool) {}
}

// Nil2 return an iter.Seq2 that yields nothing.
func Nil2[K, V any]() iter.Seq2[K, V] {
	return func(yield func(K, V) bool) {}
}

About ezpkg.io

As I work on various Go projects, I often find myself creating utility functions, extending existing packages, or developing packages to solve specific problems. Moving from one project to another, I usually have to copy or rewrite these solutions. So I created this repository to have all these utilities and packages in one place. Hopefully, you'll find them useful as well.

For more information, see the main repository.

Author

Oliver Nguyen  github

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Nil

func Nil[V any]() iter.Seq[V]

Nil return an iter.Seq that yields nothing.

func Nil2

func Nil2[K, V any]() iter.Seq2[K, V]

Nil2 return an iter.Seq2 that yields nothing.

Types

This section is empty.

Jump to